summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/kexipart/keximacroproperty.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/macros/kexipart/keximacroproperty.h')
-rw-r--r--kexi/plugins/macros/kexipart/keximacroproperty.h44
1 files changed, 23 insertions, 21 deletions
diff --git a/kexi/plugins/macros/kexipart/keximacroproperty.h b/kexi/plugins/macros/kexipart/keximacroproperty.h
index 19f7b7ac1..b1c256e9e 100644
--- a/kexi/plugins/macros/kexipart/keximacroproperty.h
+++ b/kexi/plugins/macros/kexipart/keximacroproperty.h
@@ -36,35 +36,36 @@ class KexiMacroPropertyWidget;
* more control about the handling of our macro-properties.
*/
class KexiMacroProperty
- : public QObject
+ : public TQObject
, public KoProperty::CustomProperty
{
Q_OBJECT
+ TQ_OBJECT
friend class KexiMacroPropertyWidget;
public:
/** Constructor. */
- explicit KexiMacroProperty(KoProperty::Property* parent, KSharedPtr<KoMacro::MacroItem> macroitem, const QString& name);
+ explicit KexiMacroProperty(KoProperty::Property* tqparent, KSharedPtr<KoMacro::MacroItem> macroitem, const TQString& name);
/** Destructor. */
virtual ~KexiMacroProperty();
- /** @return the parent @a KoProperty::Property instance. */
- KoProperty::Property* parentProperty() const;
+ /** @return the tqparent @a KoProperty::Property instance. */
+ KoProperty::Property* tqparentProperty() const;
/** This function is called by @ref KoProperty::Property::setValue()
when a custom property is set.
You don't have to modify the property value, it is done by Property class.
- You just have to update child or parent properties value (m_property->parent()->setValue()).
+ You just have to update child or tqparent properties value (m_property->tqparent()->setValue()).
Note that, when calling Property::setValue, you <b>need</b> to set
useCustomProperty (3rd parameter) to false, or there will be infinite recursion. */
- virtual void setValue(const QVariant &value, bool rememberOldValue);
+ virtual void setValue(const TQVariant &value, bool rememberOldValue);
/** This function is called by @ref KoProperty::Property::value()
when a custom property is set and @ref handleValue() is true.
- You should return property's value, taken from parent's value.*/
- virtual QVariant value() const;
+ You should return property's value, taken from tqparent's value.*/
+ virtual TQVariant value() const;
/** Tells whether CustomProperty should be used to get the property's value.
You should return true for child properties, and false for others. */
@@ -75,8 +76,8 @@ class KexiMacroProperty
KSharedPtr<KoMacro::MacroItem> macroItem() const;
/** \return the name the property has in the \a KoMacro::MacroItem
- above. Is QString::null if there was no item provided. */
- QString name() const;
+ above. Is TQString() if there was no item provided. */
+ TQString name() const;
/** \return the \a KoMacro::Variable which has the name @a name()
in the item @a macroItem() . If such a variable doesn't exists NULL
@@ -85,7 +86,7 @@ class KexiMacroProperty
/** Factory function to create a new @a KoProperty::Property instance
that will use a @a KexiMacroProperty as container. */
- static KoProperty::Property* createProperty(KSharedPtr<KoMacro::MacroItem> macroitem, const QString& name);
+ static KoProperty::Property* createProperty(KSharedPtr<KoMacro::MacroItem> macroitem, const TQString& name);
signals:
@@ -110,18 +111,18 @@ class KexiMacroPropertyFactory : public KoProperty::CustomPropertyFactory
{
public:
/** Constructor. */
- explicit KexiMacroPropertyFactory(QObject* parent);
+ explicit KexiMacroPropertyFactory(TQObject* tqparent);
/** Destructor. */
virtual ~KexiMacroPropertyFactory();
/** @return a new instance of custom property for @p parent.
Implement this for property types you want to support.
- Use parent->type() to get type of the property. */
- virtual KoProperty::CustomProperty* createCustomProperty(KoProperty::Property* parent);
+ Use tqparent->type() to get type of the property. */
+ virtual KoProperty::CustomProperty* createCustomProperty(KoProperty::Property* tqparent);
/** @return a new instance of custom property for @p property.
Implement this for property editor types you want to support.
- Use parent->type() to get type of the property. */
+ Use tqparent->type() to get type of the property. */
virtual KoProperty::Widget* createCustomWidget(KoProperty::Property* property);
/** Initializes this factory. The factory may register itself at
@@ -139,21 +140,22 @@ class KexiMacroPropertyFactory : public KoProperty::CustomPropertyFactory
class KexiMacroPropertyWidget : public KoProperty::Widget
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Constructor. */
- explicit KexiMacroPropertyWidget(KoProperty::Property* property, QWidget* parent = 0);
+ explicit KexiMacroPropertyWidget(KoProperty::Property* property, TQWidget* tqparent = 0);
/** Destructor. */
virtual ~KexiMacroPropertyWidget();
/** @return the value this widget has. */
- virtual QVariant value() const;
+ virtual TQVariant value() const;
/** Set the value @p value this widget has. If @p emitChange is true,
the @p KoProperty::Widget::valueChanged signal will be emitted. */
- virtual void setValue(const QVariant& value, bool emitChange=true);
+ virtual void setValue(const TQVariant& value, bool emitChange=true);
- //virtual void drawViewer(QPainter *p, const QColorGroup &cg, const QRect &r, const QVariant &value);
+ //virtual void drawViewer(TQPainter *p, const TQColorGroup &cg, const TQRect &r, const TQVariant &value);
protected:
@@ -165,7 +167,7 @@ class KexiMacroPropertyWidget : public KoProperty::Widget
/** Called if the text in the KComboBox changed. */
void slotComboBoxChanged();
- /** Called if an item in the QListBox of the KComboBox got activated. */
+ /** Called if an item in the TQListBox of the KComboBox got activated. */
void slotComboBoxActivated();
/** Called if the @a KoProperty::Widget of the EditListBoxItem got changed. */
@@ -110,18 +111,18 @@ class KexiMacroPropertyFactory : public KoProperty::CustomPropertyFactory
/** Destructor. */
virtual ~KexiMacroPropertyFactory();
- /** @return a new instance of custom property for @p parent.
+ /** @return a new instance of custom property for @p tqparent.
Implement this for property types you want to support.